@@ -38,7 +38,8 @@ class DiscordpyPDAImplementation(engi.ConversationListImplementation):
         return "discordpy"
 
     def __init__(self, name: str, bot_token: str,
-                 mode: DiscordpyPDAMode = DiscordpyPDAMode.CHANNEL_USER):
+                 mode: DiscordpyPDAMode = DiscordpyPDAMode.CHANNEL_USER,
+                 intents: discord.Intents = discord.Intents.default()):
 
         super().__init__(name=name)
 
@@ -84,7 +85,7 @@ class DiscordpyPDAImplementation(engi.ConversationListImplementation):
                     projectile=DiscordMessageDeleted(event=message)
                 )
 
-        self.client: d.Client = CustomClient()
+        self.client: d.Client = CustomClient(intents=intents)
         """
         .. todo:: Document this.        
         """
@@ -109,10 +110,8 @@ class DiscordpyPDAImplementation(engi.ConversationListImplementation):
         else:
             raise TypeError("Invalid mode")
 
-
     async def run(self) -> t.NoReturn:
-        await self.client.login(token=self.bot_token)
-        await self.client.connect(reconnect=True)
+        await self.client.start(self.bot_token, bot=True, reconnect=True)
 
 
 __all__ = (
